==> igniteui-angular-charts-17.2.1.tgz: package/esm5/lib/ScatterLineSeries.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { ScatterBase } from "./ScatterBase";
import { UnknownValuePlotting_$type } from "igniteui-angular-core";
import { DependencyProperty } from "igniteui-angular-core";
import { Point_$type, typeCast, runOn, Number_$type, enumGetBox, markType, markDep } from "igniteui-angular-core";
import { OwnedPoint } from "./OwnedPoint";
import { ScatterFrame } from "./ScatterFrame";
import { ScatterLineSeriesView } from "./ScatterLineSeriesView";
import { Defaults } from "./Defaults";
import { PathGeometry } from "igniteui-angular-core";
import { Rect } from "igniteui-angular-core";
import { ScalerParams } from "./ScalerParams";
import { Clipper } from "igniteui-angular-core";
import { List$1 } from "igniteui-angular-core";
import { RectUtil } from "igniteui-angular-core";
import { PolyLineSegment } from "igniteui-angular-core";
import { PathFigure } from "igniteui-angular-core";
import { PathFigureCollection } from "igniteui-angular-core";
import { Flattener } from "igniteui-angular-core";
import { PropertyMetadata } from "igniteui-angular-core";
import { boxArray$1, arrayShallowClone } from "igniteui-angular-core";
import { isNaN_ } from "igniteui-angular-core";
/**
 * @hidden
 */
var ScatterLineSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ScatterLineSeries, _super);
    function ScatterLineSeries() {
        var _this = _super.call(this) || this;
        _this.ab = ScatterLineSeries.$;
        _this.v1 = new ScatterFrame();
        _this.v3 = new ScatterFrame();
        _this.vz = new ScatterFrame();
        var a = function (b, c, d) {
            var e = _this.c7.indexOf(b.a);
            if (e == -1 || e == 0) {
                return b;
            }
            var f = _this.c7.item(e - 1);
            var g;
            if (!((function () { var h = c.g.tryGetValue(f, g); g = h.p1; return h.ret; })())) {
                return b;
            }
            return g;
        };
        _this.v1.o = a;
        _this.v3.o = a;
        _this.vz.o = a;
        return _this;
    }
    ScatterLineSeries.prototype.bg = function () {
        return new ScatterLineSeries();
    };
    ScatterLineSeries.prototype.get_ey = function () {
        return true;
    };
    ScatterLineSeries.prototype.ch = function () {
        return new ScatterLineSeriesView(this);
    };
    ScatterLineSeries.prototype.wq = function () {
        return true;
    };
    ScatterLineSeries.prototype.iq = function () {
        if (!isNaN_(this.ip)) {
            return _super.prototype.iq.call(this);
        }
        return Defaults.x;
    };
    ScatterLineSeries.prototype.f5 = function (a, b) {
        if (this.ue(a, b)) {
            return true;
        }
        if (this.zg(a, b)) {
            return true;
        }
        return false;
    };
    ScatterLineSeries.prototype.zg = function (a, b) {
        var c = this.ck;
        var d = c.dj;
        return this.f6(a, b, d.an);
    };
    ScatterLineSeries.prototype.x7 = function (a, b) {
        var _this = this;
        _super.prototype.x7.call(this, a, b);
        a.m.clear();
        a.u.clear();
        var c = b.by;
        var d = b.bx;
        var e = this.getEffectiveViewport1(b);
        var f = this.hk * this.hk;
        var g = 0;
        if (this.wb != null) {
            g = this.wb.count;
        }
        if (this.wc != null) {
            g = Math.min(this.wc.count, g);
        }
        var h = new ScalerParams(0, c, d, this.vv.d, e);
        var i = ((function () {
            var $ret = new ScalerParams(0, c, d, _this.vv.e, e);
            $ret.b = _this.h3();
            return $ret;
        })());
        var j = arrayShallowClone(this.wb.asArray());
        var k = arrayShallowClone(this.wc.asArray());
        this.xAxis.hn(boxArray$1(j), 0, j.length, h);
        this.yAxis.hn(boxArray$1(k), 0, k.length, i);
        var l = d.top - 10;
        var m = d.bottom + 10;
        var n = d.left - 10;
        var o = d.right + 10;
        var p = ((function () {
            var $ret = new Clipper(1, n, m, o, l, false);
            $ret.i = a.m;
            return $ret;
        })());
        for (var q = 0; q < g;) {
            var r = q;
            ++q;
            if (g > this.w2) {
                while (q < g) {
                    var s = j[q] - j[r];
                    var t = k[q] - k[r];
                    var u = s * s + t * t;
                    if (u >= f) {
                        break;
                    }
                    ++q;
                }
                p.j(this.zn(j, k, r, q - 1));
            }
            else {
                var v = new OwnedPoint();
                v.c = { $type: Point_$type, x: j[r], y: k[r] };
                v.a = this.c7.item(r);
                if (!a.u.containsKey(v.a)) {
                    a.u.addItem(v.a, v);
                }
            }
        }
        if (g > this.w2) {
            p.i = null;
        }
    };
    ScatterLineSeries.prototype.zn = function (a, b, c, d) {
        if (c == d) {
            return { $type: Point_$type, x: a[c], y: b[c] };
        }
        var e = 0;
        var f = 0;
        var g = (d - c + 1);
        for (var h = c; h <= d; ++h) {
            e += a[h];
            f += b[h];
        }
        return { $type: Point_$type, x: e / g, y: f / g };
    };
    ScatterLineSeries.prototype.get_wk = function () {
        return true;
    };
    ScatterLineSeries.prototype.yi = function (a, b) {
        b.c7(false);
        _super.prototype.yi.call(this, a, b);
        var c = this.getEffectiveViewport1(b);
        var d = new Rect(0, b.bx.left, b.bx.top, b.bx.width, b.bx.height);
        d = RectUtil.t(d, this.hl, this.hl);
        this.yb(a, new Clipper(0, d, false));
        var e = typeCast(ScatterLineSeriesView.$, b);
        this.v8.az(this, this.wp(), runOn(this, this.vj));
        var f = false;
        var g = this.v8.b;
        if (g != null) {
            f = true;
        }
        if (f) {
            this.x3(-1, this.wb.count, b.q);
        }
        this.v8.ad(e.dj, true, false, true, false);
        this.zl(e.dj, a.m.count, function (h) { return a.m._inner[h].x; }, function (h) { return a.m._inner[h].y; }, this.zf, this.hk);
    };
    ScatterLineSeries.prototype.zl = function (a, b, c, d, e, f) {
        var g = new PathGeometry();
        a.an = g;
        g.c = new PathFigureCollection();
        var h = new List$1(PolyLineSegment.$, 0);
        var i = 0;
        for (var j = 0; j < b; j++) {
            if (isNaN_(c(j)) || isNaN_(d(j))) {
                var k = j - i;
                if (k > 0) {
                    if (e == 1 || h.count == 0) {
                        var l = new PolyLineSegment();
                        h.add(l);
                    }
                    this.zk(h._inner[h.count - 1]._points, i, j - 1, c, d, f);
                }
                i = j + 1;
            }
        }
        if (e == 1 || h.count == 0) {
            var m = new PolyLineSegment();
            h.add(m);
        }
        this.zk(h._inner[h.count - 1]._points, i, b - 1, c, d, f);
        var _loop_1 = function (n) {
            var o = h._inner[n];
            if (o._points.count > 0) {
                var p = ((function () {
                    var $ret = new PathFigure();
                    $ret.startPoint = o._points._inner[0];
                    return $ret;
                })());
                p._segments.add(o);
                g.c.add(p);
            }
        };
        for (var n = 0; n < h.count; n++) {
            _loop_1(n);
        }
    };
    ScatterLineSeries.prototype.zh = function (a, b, c, d, e, f) {
        var g = new List$1(Number_$type, 0);
        var h = d;
        var i = e;
        var j = i - h + 1;
        while (j > 0) {
            if (j <= 512) {
                Flattener.c(g, b, c, h, i, f);
                h = i + 1;
            }
            else {
                var k = h + 512 - 1;
                Flattener.c(g, b, c, h, k, f);
                h = k + 1;
            }
            j = i - h + 1;
        }
        return g;
    };
    ScatterLineSeries.prototype.zk = function (a, b, c, d, e, f) {
        if (c > -1) {
            var g = !isNaN_(this.ip) ? f : 1;
            var h = this.zh(new List$1(Number_$type, 0), d, e, b, c, g);
            var i = void 0;
            for (var j = 0; j < h.count; j++) {
                i = h.item(j);
                a.add({ $type: Point_$type, x: d(i), y: e(i) });
            }
        }
    };
    ScatterLineSeries.prototype.o9 = function (a, b, c, d) {
        _super.prototype.o9.call(this, a, b, c, d);
        switch (b) {
            case ScatterLineSeries.$$p[0]:
                this.pq(false);
                this.om();
                break;
        }
    };
    ScatterLineSeries.$t = markType(ScatterLineSeries, 'ScatterLineSeries', ScatterBase.$);
    ScatterLineSeries.$$p = markDep(DependencyProperty, PropertyMetadata, ScatterLineSeries, 'raisePropertyChanged', ['UnknownValuePlotting:zf:zm', [UnknownValuePlotting_$type, enumGetBox(UnknownValuePlotting_$type, 1)]]);
    return ScatterLineSeries;
}(ScatterBase));
export { ScatterLineSeries };

==> igniteui-angular-charts-17.3.0.tgz: package/esm5/lib/ScatterLineSeries.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { ScatterBase } from "./ScatterBase";
import { UnknownValuePlotting_$type } from "igniteui-angular-core";
import { DependencyProperty } from "igniteui-angular-core";
import { Point_$type, typeCast, runOn, Number_$type, enumGetBox, markType, markDep } from "igniteui-angular-core";
import { OwnedPoint } from "./OwnedPoint";
import { ScatterFrame } from "./ScatterFrame";
import { ScatterLineSeriesView } from "./ScatterLineSeriesView";
import { Defaults } from "./Defaults";
import { PathGeometry } from "igniteui-angular-core";
import { Rect } from "igniteui-angular-core";
import { ScalerParams } from "./ScalerParams";
import { Clipper } from "igniteui-angular-core";
import { List$1 } from "igniteui-angular-core";
import { RectUtil } from "igniteui-angular-core";
import { PolyLineSegment } from "igniteui-angular-core";
import { PathFigure } from "igniteui-angular-core";
import { PathFigureCollection } from "igniteui-angular-core";
import { Flattener } from "igniteui-angular-core";
import { PropertyMetadata } from "igniteui-angular-core";
import { boxArray$1, arrayShallowClone } from "igniteui-angular-core";
import { isNaN_ } from "igniteui-angular-core";
/**
 * @hidden
 */
var ScatterLineSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ScatterLineSeries, _super);
    function ScatterLineSeries() {
        var _this = _super.call(this) || this;
        _this.ab = ScatterLineSeries.$;
        _this.vx = new ScatterFrame();
        _this.vz = new ScatterFrame();
        _this.vv = new ScatterFrame();
        var a = function (b, c, d) {
            var e = _this.c7.indexOf(b.a);
            if (e == -1 || e == 0) {
                return b;
            }
            var f = _this.c7.item(e - 1);
            var g;
            if (!((function () { var h = c.g.tryGetValue(f, g); g = h.p1; return h.ret; })())) {
                return b;
            }
            return g;
        };
        _this.vx.o = a;
        _this.vz.o = a;
        _this.vv.o = a;
        return _this;
    }
    ScatterLineSeries.prototype.bc = function () {
        return new ScatterLineSeries();
    };
    ScatterLineSeries.prototype.get_ey = function () {
        return true;
    };
    ScatterLineSeries.prototype.cd = function () {
        return new ScatterLineSeriesView(this);
    };
    ScatterLineSeries.prototype.wr = function () {
        return true;
    };
    ScatterLineSeries.prototype.iq = function () {
        if (!isNaN_(this.ip)) {
            return _super.prototype.iq.call(this);
        }
        return Defaults.x;
    };
    ScatterLineSeries.prototype.f5 = function (a, b) {
        if (this.uf(a, b)) {
            return true;
        }
        if (this.zh(a, b)) {
            return true;
        }
        return false;
    };
    ScatterLineSeries.prototype.zh = function (a, b) {
        var c = this.cg;
        var d = c.dj;
        return this.f6(a, b, d.an);
    };
    ScatterLineSeries.prototype.x8 = function (a, b) {
        var _this = this;
        _super.prototype.x8.call(this, a, b);
        a.m.clear();
        a.u.clear();
        var c = b.by;
        var d = b.bx;
        var e = this.getEffectiveViewport1(b);
        var f = this.hk * this.hk;
        var g = 0;
        if (this.wc != null) {
            g = this.wc.count;
        }
        if (this.wd != null) {
            g = Math.min(this.wd.count, g);
        }
        var h = new ScalerParams(0, c, d, this.vr.d, e);
        var i = ((function () {
            var $ret = new ScalerParams(0, c, d, _this.vr.e, e);
            $ret.b = _this.h3();
            return $ret;
        })());
        var j = arrayShallowClone(this.wc.asArray());
        var k = arrayShallowClone(this.wd.asArray());
        this.xAxis.hn(boxArray$1(j), 0, j.length, h);
        this.yAxis.hn(boxArray$1(k), 0, k.length, i);
        var l = d.top - 10;
        var m = d.bottom + 10;
        var n = d.left - 10;
        var o = d.right + 10;
        var p = ((function () {
            var $ret = new Clipper(1, n, m, o, l, false);
            $ret.i = a.m;
            return $ret;
        })());
        for (var q = 0; q < g;) {
            var r = q;
            ++q;
            if (g > this.w3) {
                while (q < g) {
                    var s = j[q] - j[r];
                    var t = k[q] - k[r];
                    var u = s * s + t * t;
                    if (isNaN_(u) || u >= f) {
                        break;
                    }
                    ++q;
                }
                p.j(this.zo(j, k, r, q - 1));
            }
            else {
                var v = new OwnedPoint();
                v.c = { $type: Point_$type, x: j[r], y: k[r] };
                v.a = this.c7.item(r);
                if (!a.u.containsKey(v.a)) {
                    a.u.addItem(v.a, v);
                }
            }
        }
        if (g > this.w3) {
            p.i = null;
        }
    };
    ScatterLineSeries.prototype.zo = function (a, b, c, d) {
        if (c == d) {
            return { $type: Point_$type, x: a[c], y: b[c] };
        }
        var e = 0;
        var f = 0;
        var g = (d - c + 1);
        for (var h = c; h <= d; ++h) {
            e += a[h];
            f += b[h];
        }
        return { $type: Point_$type, x: e / g, y: f / g };
    };
    ScatterLineSeries.prototype.get_wl = function () {
        return true;
    };
    ScatterLineSeries.prototype.yj = function (a, b) {
        b.c7(false);
        _super.prototype.yj.call(this, a, b);
        var c = this.getEffectiveViewport1(b);
        var d = new Rect(0, b.bx.left, b.bx.top, b.bx.width, b.bx.height);
        d = RectUtil.t(d, this.hl, this.hl);
        this.yc(a, new Clipper(0, d, false));
        var e = typeCast(ScatterLineSeriesView.$, b);
        this.v4.az(this, this.wq(), runOn(this, this.vk));
        var f = false;
        var g = this.v4.b;
        if (g != null) {
            f = true;
        }
        if (f) {
            this.x4(-1, this.wc.count, b.q);
        }
        this.v4.ad(e.dj, true, false, true, false);
        this.zm(e.dj, a.m.count, function (h) { return a.m._inner[h].x; }, function (h) { return a.m._inner[h].y; }, this.zg, this.hk);
    };
    ScatterLineSeries.prototype.zm = function (a, b, c, d, e, f) {
        var g = new PathGeometry();
        a.an = g;
        g.c = new PathFigureCollection();
        var h = new List$1(PolyLineSegment.$, 0);
        var i = 0;
        for (var j = 0; j < b; j++) {
            if (isNaN_(c(j)) || isNaN_(d(j))) {
                var k = j - i;
                if (k > 0) {
                    if (e == 1 || h.count == 0) {
                        var l = new PolyLineSegment();
                        h.add(l);
                    }
                    this.zl(h._inner[h.count - 1]._points, i, j - 1, c, d, f);
                }
                i = j + 1;
            }
        }
        if (e == 1 || h.count == 0) {
            var m = new PolyLineSegment();
            h.add(m);
        }
        this.zl(h._inner[h.count - 1]._points, i, b - 1, c, d, f);
        var _loop_1 = function (n) {
            var o = h._inner[n];
            if (o._points.count > 0) {
                var p = ((function () {
                    var $ret = new PathFigure();
                    $ret.startPoint = o._points._inner[0];
                    return $ret;
                })());
                p._segments.add(o);
                g.c.add(p);
            }
        };
        for (var n = 0; n < h.count; n++) {
            _loop_1(n);
        }
    };
    ScatterLineSeries.prototype.zi = function (a, b, c, d, e, f) {
        var g = new List$1(Number_$type, 0);
        var h = d;
        var i = e;
        var j = i - h + 1;
        while (j > 0) {
            if (j <= 512) {
                Flattener.c(g, b, c, h, i, f);
                h = i + 1;
            }
            else {
                var k = h + 512 - 1;
                Flattener.c(g, b, c, h, k, f);
                h = k + 1;
            }
            j = i - h + 1;
        }
        return g;
    };
    ScatterLineSeries.prototype.zl = function (a, b, c, d, e, f) {
        if (c > -1) {
            var g = !isNaN_(this.ip) ? f : 1;
            var h = this.zi(new List$1(Number_$type, 0), d, e, b, c, g);
            var i = void 0;
            for (var j = 0; j < h.count; j++) {
                i = h.item(j);
                a.add({ $type: Point_$type, x: d(i), y: e(i) });
            }
        }
    };
    ScatterLineSeries.prototype.pa = function (a, b, c, d) {
        _super.prototype.pa.call(this, a, b, c, d);
        switch (b) {
            case ScatterLineSeries.$$p[0]:
                this.pr(false);
                this.om();
                break;
        }
    };
    ScatterLineSeries.$t = markType(ScatterLineSeries, 'ScatterLineSeries', ScatterBase.$);
    ScatterLineSeries.$$p = markDep(DependencyProperty, PropertyMetadata, ScatterLineSeries, 'raisePropertyChanged', ['UnknownValuePlotting:zg:zn', [UnknownValuePlotting_$type, enumGetBox(UnknownValuePlotting_$type, 1)]]);
    return ScatterLineSeries;
}(ScatterBase));
export { ScatterLineSeries };
